@@ -1,7 +1,7 @@
 """Abbreviation Bibliography IdCooker class"""
 
 # Zope stuff
-from Globals import InitializeClass
+from App.class_init import InitializeClass
 from App.Dialogs import MessageDialog
 
 # CMF stuff
@@ -19,12 +19,12 @@ class AbbrevIdCooker(BibliographyIdCooker):
     year.
     """
 
-    __implements__ = (IBibliographyIdCooker ,)
+
 
     meta_type = "Abbreviation Bibliography ID Cooker"
 
     def __init__(self,
-                 id = 'etal',
+                 id = 'abbrev',
                  title = "Abbreviation Bibliography ID Cooker"):
         """
         initializes id and title
@@ -38,27 +38,27 @@ class AbbrevIdCooker(BibliographyIdCooker):
         """
 
         # AUTHORS
-	namepart='nobody'
+        namepart='nobody'
         if self._refHasAuthorNames(ref):
             lastnames = []
             for each in ref['authors']:
                 if each.get('lastname', None):
-		    lastnames.append(each['lastname'])
-            
-	    if len(lastnames) > 1:
+                    lastnames.append(each['lastname'])
+
+            if len(lastnames) > 1:
                 namepart = '%s' % ''.join([ lastname[0] for lastname in lastnames ])
-	    elif len(lastnames) == 1:
-	        namepart = lastnames[0][:3]
-	    else:
-		pass	
-	
-	# PUBLICATION YEAR
-	if ref.get('publication_year', None):
-	    yearpart = str(ref['publication_year'])
-	else:
-	    yearpart = "1000"
-	
-	return  namepart + yearpart
+            elif len(lastnames) == 1:
+                namepart = lastnames[0][:3]
+            else:
+                pass
+
+        # PUBLICATION YEAR
+        if ref.get('publication_year', None):
+            yearpart = str(ref['publication_year'])
+        else:
+            yearpart = "1000"
+
+        return  namepart + yearpart
 
 
 InitializeClass(AbbrevIdCooker)
@@ -67,7 +67,7 @@ InitializeClass(AbbrevIdCooker)
 def manage_addAbbrevIdCooker(self, REQUEST=None):
     """ """
     try:
-        self._setObject('etal', AbbrevIdCooker())
+        self._setObject('abbrev', AbbrevIdCooker())
     except:
         return MessageDialog(
             title='Bibliography tool warning message',
